@@ -151,11 +151,12 @@ fn main()  {
     // vector of structures Arena for parasite path trees
     // ---------------------------------------------------------
     let mut tree_host_pipe: ArenaTree<String> = ArenaTree::default();
+    let mut global_roots: std::vec::Vec<usize> = Vec::new();
     let mut path_para_trees:std::vec::Vec<ArenaTree<String>> = Vec::new();
     // ---------------------------------------------------------
     // Fill  host pipe tree and is roots and path parasite trees
     // ---------------------------------------------------------
-    read_recphyloxml(infile_ph,&mut tree_host_pipe,&mut path_para_trees);
+    read_recphyloxml_multi(infile_ph,&mut tree_host_pipe,&mut path_para_trees, &mut global_roots);
     let  nb_parasite_path =  path_para_trees.len().clone();
     println!("Number of pipe parasite trees in gene-parasite file : {}",nb_parasite_pipe);
     println!("Number of path parasite trees in parasite-host file : {}",nb_parasite_path);
